﻿// For an introduction to the Page Control template, see the following documentation:
// http://go.microsoft.com/fwlink/?LinkId=232511
(function () {
    "use strict";

    var serviceItem = null;
    var locator = null;
    var lat;
    var long;

    WinJS.UI.Pages.define("/pages/create/create.html", {
        // This function is called whenever a user navigates to this page. It
        // populates the page elements with the app's data.
        ready: function (element, options) {
            
            //connect appbar commands
            var btnSend = document.getElementById("btnSend");
            btnSend.addEventListener("click", btnSend_Click, false);

            //load the locator
            locator = new Windows.Devices.Geolocation.Geolocator();
            var locatorPromise = locator.getGeopositionAsync();
            locatorPromise.then(
                function complete(position) {
                    lat = position.coordinate.latitude;
                    long = position.coordinate.longitude;                
                },
                function error(ex) {
                    //handle the error
                });

            //set the name of the service
            serviceItem = options.serviceItem;
            document.getElementById("serviceName").innerText = serviceItem.service_name;

            //get service description if the service has meta data
            if (serviceItem.metadata) {
                Data.GetServiceDescription(serviceItem.service_code).done(
                    function complete(result) {
                        if (result.status == 200) {
                            var serviceDescription = JSON.parse(result.responseText);

                            var dynamicObject = document.getElementById("custom-content");
                            serviceDescription.attributes.forEach(function (attribute) {
                                if (attribute.variable) {
                                    //if it is a variable type then detect the input type and render
                                    switch (attribute.datatype) {
                                        case "string":
                                            //create a label and input box with type text
                                            dynamicObject.appendChild(ControlFactory.CreateTextControl(attribute, true, "p", "text"));
                                            break;
                                        case "number":
                                            //create a label and input box with type number
                                            dynamicObject.appendChild(ControlFactory.CreateTextControl(attribute, true, "p", "number"));
                                            break;
                                        case "datetime":
                                            //create a label and input box with type datetime
                                            dynamicObject.appendChild(ControlFactory.CreateTextControl(attribute, true, "p", "datetime"));
                                            break;
                                        case "text":
                                            //create a label and a textarea
                                            dynamicObject.appendChild(ControlFactory.CreateTextControl(attribute, true, "p", "textblock"));
                                            break;
                                        case "singlevaluelist":
                                            //create a label and an select list
                                            dynamicObject.appendChild(ControlFactory.CreateSelectListControl(attribute, true, "p"));
                                            break;
                                        case "multivaluelist":
                                            //currently unsupported
                                            break;
                                    }
                                }
                            });
                        }
                    },
                    function err(result) {
                        var e = result;
                    },
                    function progress(result) {

                    });

            }
        },

        unload: function () {
            // TODO: Respond to navigations away from this page.
        },

        updateLayout: function (element, viewState, lastViewState) {
            /// <param name="element" domElement="true" />

            // TODO: Respond to changes in viewState.
        }
    });
    
    function btnSend_Click(e) {
        var options = {};
        options.address = document.getElementById("txtAddress").value;        

        if ((lat == undefined || long == undefined) && options.address == "")
            return;
        
        options.description = document.getElementById("txtDescription").innerText;
        options.serviceCode = serviceItem.service_code;

        if (lat === undefined)
            lat = 0.0;

        if (long === undefined)
            long = 0.0;

        options.lat = lat;
        options.long = long;

        options.firstName = document.getElementById("txtFN").value;
        options.lastName = document.getElementById("txtLN").value;
        options.emailAddress = document.getElementById("txtEmail").value;
        options. phoneNumber = document.getElementById("txtPhone").value;
        options.attributes = new Array();
        //collect up all the attribute-codes
        var attributeCollection = document.querySelectorAll("[data-attribute-code]");
        for (var i = 0; i < attributeCollection.length; i++) {
            var value = document.getElementById(attributeCollection[i].id).value;
            var code = document.getElementById(attributeCollection[i].id).getAttribute("data-attribute-code");

            options.attributes.push({ code: code, value: value });
        }
        
        Data.PostRequest(options);
    }

})();
