﻿(function () {
    'use strict';

    function createTextControlGroup(descriptionAttribute, includeLabel, parentTag, inputType) {
        var rootElement = document.createElement(parentTag);
        var textBox = document.createElement("input");
        textBox.setAttribute("type") = inputType;                           //support HTML5 input types
        textBox.setAttribute("data-attribute-code", descriptionAttribute.code);       //point out how this uses the HTML5 data- attribute
        textBox.id = "input" + descriptionAttribute.code

        if (inputType == "textblock") {
            textBox.setAttribute("rows") = "6";
            textBox.setAttribute("cols") = "45";
        }

        if (descriptionAttribute.required)
            textBox.setAttribute("required", "required");

        if (includeLabel) {
            var label = document.createElement("label");
            label.textContent = descriptionAttribute.description;
            rootElement.appendChild(label);
        }
        else
            textBox.setAttribute("placeholder", descriptionAttribute.description);

        rootElement.appendChild(textBox);
        return rootElement;

        
    }

    function createDropDownControlGroup(descriptionAttribute, includeLabel, parentTag) {
        var rootElement = document.createElement(parentTag);
        var select = document.createElement("select");
        select.id = "select" + descriptionAttribute.code;

        if (includeLabel) {
            var label = document.createElement("label");
            label.textContent = descriptionAttribute.description;
            rootElement.appendChild(label);
        }
        else {
            select.appendChild(createOption("", descriptionAttribute.description));
        }

        descriptionAttribute.values.forEach(function (value) {
            select.appendChild(createOption(value.key, value.name));
        });
        select.setAttribute("data-attribute-code", descriptionAttribute.code);
        rootElement.appendChild(select);
        return rootElement
    }

    function createOption(key, value) {
        var option = document.createElement("option");
        option.value = key;
        option.text = value;
        return option;
    }


    WinJS.Namespace.define("ControlFactory", {
        CreateTextControl: createTextControlGroup,
        CreateSelectListControl: createDropDownControlGroup
    });

})();