﻿(function () {

    "use strict";

    //service list generation
    var serviceList = new WinJS.Binding.List();         //is the list of services used for filtering
    var serviceGroups = serviceList.createGrouped(
        function groupKeySelector(item) { return item.group; },
        function groupDataSelector(item) { return item; }
    );

    var serviceDescription = null;
    var httpClient = new Windows.Web.Http.HttpClient();


    var requestList = new WinJS.Binding.List(); //is the list of requests to be displayed by the user


    function getRequests(serviceRequestId, status, startDate, endDate, serviceCode) {
        ///<summary>Gets a list of requests based on the service code</summary>
        ///<returns>List of requests</returns>

        var url = "";
        if (serviceRequestId !== "")
            url = "http://311.baltimorecity.gov/open311/v2/requests.json?jurisdiction_id=baltimorecity.gov&service_request_id=" + serviceRequestId;
        else {
            url = "http://311.baltimorecity.gov/open311/v2/requests.json?jurisdiction_id=baltimorecity.gov";

            if (startDate !== "")
                url += "&start_date=" + startDate.toISOString();

            if (endDate !== "")
                url += "&end_date=" + endDate.toISOString();

            if (serviceCode !== "")
                url += "&service_code=" + serviceCode;

            if (status !== "")
                url += "&status=" + status;

        }
        
        return httpClient.getStringAsync(new Windows.Foundation.Uri(url))
            .then(
                function complete(results) {
                    var items = JSON.parse(results);
                    items.forEach(function (item) {
                        if (requestList.indexOf(item) == -1) {
                            item.backgroundImage = "http://dev.virtualearth.net/REST/v1/Imagery/Map/AerialWithLabels/" + item.lat + "," + item.long + "/15?mapSize=100,100&format=png&pushpin=" + item.lat + "," + item.long + ";65;&key=[BING MAPS KEY]";
                            requestList.push(item);
                        }
                    });
                });
    }


    function getServices() {

        httpClient.getStringAsync(new Windows.Foundation.Uri("http://311.baltimorecity.gov/open311/v2/services.json"))
            .then(
                function complete(result) {
                    var items = JSON.parse(result);
                    items.forEach(function (item) {
                        item.backgroundImage = "/images/icons/" + item.group + ".png";
                        serviceList.push(item);
                    });
                }
            );

    }

    function getServiceDescription(serviceCode) {
        return httpClient.getStringAsync(new Windows.Foundation.Uri("http://311.baltimorecity.gov/open311/v2/services/" + serviceCode + ".json?jurisdiction_id=baltimorecity.gov"));
    }

    function postRequest(options) {
        var data = {
            api_key: "[Open311 KEY]",
            service_code: options.serviceCode,
            lat: options.lat,
            long: options.long,
            address_string: options.address_string,
            address_id: options.address_id,
            email: options.email,
            device_id: options.device_id,
            account_id: options.account_id,
            first_name: options.first_name,
            last_name: options.last_name,
            phone: options.phone,
            description: options.description,
            media_url: options.media_url
        }

        options.attributes.forEach(function (attribute) {
            data["attribute[" + attribute.code + "]"] = encodeURIComponent(attribute.value);
        });

        
        var strData = "";
        for (var key in data) {
            if (data.hasOwnProperty(key)) {
                if(data[key] !== "")
                    strData += key + "=" + data[key] + "&";
            }
        }

        var httpContent = new Windows.Web.Http.HttpStringContent(strData, Windows.Storage.Streams.UnicodeEncoding.utf8, "application/x-www-form-urlencoded; charset=utf-8");
        return httpClient.postAsync(new Windows.Foundation.Uri("http://311.baltimorecity.gov/open311/v2/requests.json"), httpContent).then(
            function complete(result) {
                //do something with the result
                var something = result;
            },
            function error(ex){
                var e = ex;   
            });
    }


    WinJS.Namespace.define("Data", {
        services: serviceGroups,
        serviceGroups: serviceGroups.groups,
        requests: requestList,
        GetServices: getServices,
        GetRequests: getRequests,
        serviceDescription: serviceDescription,
        GetServiceDescription: getServiceDescription,
        PostRequest: postRequest
    });

})();